/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED
# define YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef SERV_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define SERV_DEBUG 1
#  else
#   define SERV_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define SERV_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined SERV_DEBUG */
#if SERV_DEBUG
extern int serv_debug;
#endif

/* Token type.  */
#ifndef SERV_TOKENTYPE
# define SERV_TOKENTYPE
  enum serv_tokentype
  {
    servMASTER = 258,
    servSERVER = 259,
    servCOMMENT = 260,
    servLABEL = 261,
    servHOST = 262,
    servLASTCOMMIT = 263,
    servNETWORKS = 264,
    servGATEWAYS = 265,
    servMDTXPORT = 266,
    servSSHPORT = 267,
    servWWWPORT = 268,
    servCOLLKEY = 269,
    servUSERKEY = 270,
    servHOSTKEY = 271,
    servPROVIDE = 272,
    servCOMMA = 273,
    servCOLON = 274,
    servEQUAL = 275,
    servENDBLOCK = 276,
    servCACHESIZE = 277,
    servCACHETTL = 278,
    servQUERYTTL = 279,
    servSUPPTTL = 280,
    servUPLOADTTL = 281,
    servSERVERTTL = 282,
    servMAXSCORE = 283,
    servBADSCORE = 284,
    servPOWSUPP = 285,
    servFACTSUPP = 286,
    servFILESCORE = 287,
    servMINGEODUP = 288,
    servERROR = 289,
    servSTRING = 290,
    servNUMBER = 291,
    servSCORE = 292,
    servHASH = 293,
    servSIZE = 294,
    servTIME = 295,
    servDATE = 296
  };
#endif
/* Tokens.  */
#define servMASTER 258
#define servSERVER 259
#define servCOMMENT 260
#define servLABEL 261
#define servHOST 262
#define servLASTCOMMIT 263
#define servNETWORKS 264
#define servGATEWAYS 265
#define servMDTXPORT 266
#define servSSHPORT 267
#define servWWWPORT 268
#define servCOLLKEY 269
#define servUSERKEY 270
#define servHOSTKEY 271
#define servPROVIDE 272
#define servCOMMA 273
#define servCOLON 274
#define servEQUAL 275
#define servENDBLOCK 276
#define servCACHESIZE 277
#define servCACHETTL 278
#define servQUERYTTL 279
#define servSUPPTTL 280
#define servUPLOADTTL 281
#define servSERVERTTL 282
#define servMAXSCORE 283
#define servBADSCORE 284
#define servPOWSUPP 285
#define servFACTSUPP 286
#define servFILESCORE 287
#define servMINGEODUP 288
#define servERROR 289
#define servSTRING 290
#define servNUMBER 291
#define servSCORE 292
#define servHASH 293
#define servSIZE 294
#define servTIME 295
#define servDATE 296

/* Value type.  */
#if ! defined SERV_STYPE && ! defined SERV_STYPE_IS_DECLARED
typedef union SERV_STYPE SERV_STYPE;
union SERV_STYPE
{
#line 61 "parser/serverFile.y" /* yacc.c:1909  */

  off_t  number;
  off_t  size;
  time_t time;
  float  score;
  char   string[(MAX_SIZE_STRING+1)*2]; // keys needs more place
  char   hash[MAX_SIZE_MD5+1];

#line 153 "parser/serverFile.tab.h" /* yacc.c:1909  */
};
# define SERV_STYPE_IS_TRIVIAL 1
# define SERV_STYPE_IS_DECLARED 1
#endif



int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
/* "%code provides" blocks.  */
#line 27 "parser/serverFile.y" /* yacc.c:1909  */

/*=======================================================================
 * Version: this file is generated by BISON using serverFile.y
 * Project: MediaTeX
 * Module : server parser
 *
 * server file parser

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE SERV_STYPE

#line 191 "parser/serverFile.tab.h" /* yacc.c:1909  */

#endif /* !YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED  */
